"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CoreApiClient = void 0;
const axios_1 = __importDefault(require("axios"));
const environments_js_1 = require("../configuration/environments.js");
const scopes_js_1 = require("../configuration/scopes.js");
const affiliationsClient_js_1 = require("./affiliationsClient.js");
const auth_js_1 = require("./auth.js");
const consentsClient_js_1 = require("./consentsClient.js");
const countriesClient_js_1 = require("./countriesClient.js");
const orgsClient_js_1 = require("./orgsClient.js");
const personsClient_js_1 = require("./personsClient.js");
const relationsClient_js_1 = require("./relationsClient.js");
const roleAssignmentsClient_js_1 = require("./roleAssignmentsClient.js");
const rolesClient_js_1 = require("./rolesClient.js");
const groupsClient_js_1 = require("./groupsClient.js");
class CoreApiClient {
    get affiliations() {
        return this._affiliations;
    }
    get consents() {
        return this._consents;
    }
    get countries() {
        return this._countries;
    }
    get orgs() {
        return this._orgs;
    }
    get persons() {
        return this._persons;
    }
    get relations() {
        return this._relations;
    }
    get roles() {
        return this._roles;
    }
    get roleAssignments() {
        return this._roleAssignments;
    }
    get groups() {
        return this._groups;
    }
    constructor(config) {
        const env = config.environment;
        this.queryOptions = Object.assign(getDefaultQueryOptions(), config.queryOptions);
        this.auth = new auth_js_1.Auth({
            audience: config.customOauthAudience ??
                environments_js_1.defaultEnvironmentConfig[env].oauthAudience,
            clientId: config.clientId,
            clientSecret: config.clientSecret,
            scopes: config.scopes ??
                (env === environments_js_1.Environment.Emulator ? Object.values(scopes_js_1.Scope) : undefined),
            tokenUrl: config.customOauthTokenUrl ?? environments_js_1.defaultEnvironmentConfig[env].tokenUrl,
            customOptions: config.customOptions ??
                (env === environments_js_1.Environment.Emulator ? { orgs: "-" } : undefined),
        });
        this.basePath =
            config.customApiBaseUrl ?? environments_js_1.defaultEnvironmentConfig[env].apiBaseUrl;
        this._affiliations = new affiliationsClient_js_1.AffiliationsClient(this.basePath, this.auth, this.queryOptions);
        this._consents = new consentsClient_js_1.ConsentsClient(this.basePath, this.auth, this.queryOptions);
        this._countries = new countriesClient_js_1.CountriesClient(this.basePath, this.auth, this.queryOptions);
        this._orgs = new orgsClient_js_1.OrgsClient(this.basePath, this.auth, this.queryOptions);
        this._persons = new personsClient_js_1.PersonsClient(this.basePath, this.auth, this.queryOptions);
        this._relations = new relationsClient_js_1.RelationsClient(this.basePath, this.auth, this.queryOptions);
        this._roles = new rolesClient_js_1.RolesClient(this.basePath, this.auth, this.queryOptions);
        this._roleAssignments = new roleAssignmentsClient_js_1.RoleAssignmentsClient(this.basePath, this.auth, this.queryOptions);
        this._groups = new groupsClient_js_1.GroupsClient(this.basePath, this.auth, this.queryOptions);
    }
    async refreshTestData() {
        return axios_1.default.post(this.basePath + "/refresh-data");
    }
    async getToken() {
        return this.auth.getToken();
    }
}
exports.CoreApiClient = CoreApiClient;
function getDefaultQueryOptions() {
    return {
        includePersonsWithoutChurchAffiliation: false,
        includeInactive: [],
    };
}
