"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.GenericClient = void 0;
const axios_1 = __importDefault(require("axios"));
const api_js_1 = require("../api.js");
const error_js_1 = require("../model/error.js");
const queryParams_js_1 = require("../model/queryParams.js");
class GenericClient {
    constructor(config) {
        this.config = config;
        this.httpClient = axios_1.default.create({
            validateStatus: () => true,
        });
    }
    async create(data) {
        const url = this.config.basePath + this.config.endpointPath;
        const res = await this.httpClient.post(url, api_js_1.ObjectSerializer.serialize(data, this.config.writeTypeName), {
            headers: await this.config.auth.getHeaders(),
        });
        if (res.status === 200) {
            const result = api_js_1.ObjectSerializer.deserialize(res.data, this.config.singleResponseTypeName);
            return result;
        }
        else {
            throw error_js_1.CoreApiError.fromHttpResponse(res);
        }
    }
    async get(id, getParams = {}) {
        getParams.options = Object.assign(JSON.parse(JSON.stringify(this.config.queryOptions)), getParams.options);
        const queryParams = (0, queryParams_js_1.serializeGetQueryParams)(getParams);
        const url = this.config.basePath +
            this.config.endpointPath +
            "/" +
            id +
            "?" +
            queryParams;
        const res = await this.httpClient.get(url, {
            headers: await this.config.auth.getHeaders(),
        });
        if (res.status === 200) {
            const result = api_js_1.ObjectSerializer.deserialize(res.data, this.config.singleResponseTypeName);
            return result;
        }
        else {
            throw error_js_1.CoreApiError.fromHttpResponse(res);
        }
    }
    async find(findParams = {}) {
        findParams.options = Object.assign(JSON.parse(JSON.stringify(this.config.queryOptions)), findParams.options);
        const queryParams = (0, queryParams_js_1.serializeFindQueryParams)(findParams);
        const url = this.config.basePath + this.config.endpointPath + "?" + queryParams;
        const res = await this.httpClient.get(url, {
            headers: await this.config.auth.getHeaders(),
        });
        if (res.status === 200) {
            const result = api_js_1.ObjectSerializer.deserialize(res.data, this.config.multipleResponseTypeName);
            return result;
        }
        else {
            throw error_js_1.CoreApiError.fromHttpResponse(res);
        }
    }
    async update(id, data) {
        const url = this.config.basePath + this.config.endpointPath + "/" + id;
        const res = await this.httpClient.put(url, JSON.stringify(api_js_1.ObjectSerializer.serialize(data, this.config.writeTypeName)), {
            headers: await this.config.auth.getHeaders(),
        });
        if (res.status === 200) {
            const result = api_js_1.ObjectSerializer.deserialize(res.data, this.config.singleResponseTypeName);
            return result;
        }
        else {
            throw error_js_1.CoreApiError.fromHttpResponse(res);
        }
    }
    async remove(id) {
        const url = this.config.basePath + this.config.endpointPath + "/" + id;
        const res = await this.httpClient.delete(url, {
            headers: await this.config.auth.getHeaders(),
        });
        if (res.status === 200) {
            const result = api_js_1.ObjectSerializer.deserialize(res.data, this.config.singleResponseTypeName);
            return result;
        }
        else {
            throw error_js_1.CoreApiError.fromHttpResponse(res);
        }
    }
}
exports.GenericClient = GenericClient;
