"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.GroupMembersClient = void 0;
const axios_1 = __importDefault(require("axios"));
const api_js_1 = require("../api.js");
const genericClient_js_1 = require("./genericClient.js");
const error_js_1 = require("../model/error.js");
class GroupMembersClient {
    constructor(basePath, groupUid, auth, queryOptions) {
        this.basePath = basePath;
        this.groupUid = groupUid;
        this.auth = auth;
        this.client = new genericClient_js_1.GenericClient({
            basePath: basePath,
            endpointPath: `/groups/${groupUid}/members`,
            auth: auth,
            writeTypeName: "GroupMemberWrite",
            singleResponseTypeName: "WrappedGroupMember",
            multipleResponseTypeName: "WrappedWithMetaArrayGroupMember",
            queryOptions: queryOptions,
        });
    }
    async create(groupMember) {
        return this.client.create(groupMember);
    }
    async remove(id) {
        return this.client.remove(id);
    }
    async removeByPersonUid(personUid) {
        const url = `${this.basePath}/groups/${this.groupUid}/members?personUid=${personUid}`;
        const res = await axios_1.default.delete(url, {
            headers: await this.auth.getHeaders(),
            validateStatus: () => true,
        });
        if (res.status === 200) {
            const result = api_js_1.ObjectSerializer.deserialize(res.data, "WrappedGroupMember");
            return result;
        }
        else {
            throw error_js_1.CoreApiError.fromHttpResponse(res);
        }
    }
    async get(id, query = {}) {
        return this.client.get(id, query);
    }
    async find(findParams = {}) {
        return this.client.find(findParams);
    }
}
exports.GroupMembersClient = GroupMembersClient;
