export type Filter<T> = T extends (infer R)[] ? R extends object ? RelationFilter<R> : ArrayFilter<R> : T extends Record<string, any> ? ObjectFilter<T> : T extends string ? StringFilter : T extends number | Date ? EndFilter<T> : never;
type RelationFilter<T> = Filter<T> | {
    _some?: Filter<T>;
    _none?: Filter<T>;
};
type ObjectFilter<T extends Record<string, any>> = {
    [K in keyof T]?: Filter<T[K]>;
} & {
    _and?: ObjectFilter<T>[];
    _or?: ObjectFilter<T>[];
};
type EndFilter<T> = {
    _eq?: T;
    _ne?: T;
    _gt?: T;
    _gte?: T;
    _lt?: T;
    _lte?: T;
    _in?: T[];
    _nin?: T[];
    _null?: true;
    _nnull?: true;
    _and?: EndFilter<T>[];
    _or?: EndFilter<T>[];
};
type StringFilter = EndFilter<string> & {
    _starts_with?: string;
    _nstarts_with?: string;
    _ends_with?: string;
    _nends_with?: string;
    _contains?: string;
    _ncontains?: string;
    _and?: StringFilter[];
    _or?: StringFilter[];
};
type ArrayFilter<T> = {
    _contains?: T[];
    _ncontains?: T[];
    _and?: ArrayFilter<T>[];
    _or?: ArrayFilter<T>[];
};
export {};
