"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const helpers_js_1 = require("./helpers.js");
const auth_js_1 = require("../api/auth.js");
const sinon_1 = __importDefault(require("sinon"));
const environments_js_1 = require("../configuration/environments.js");
describe("Auth", async () => {
    const auth = new auth_js_1.Auth({
        audience: environments_js_1.defaultEnvironmentConfig[environments_js_1.Environment.Emulator].oauthAudience,
        clientId: "0000",
        clientSecret: "0000",
        tokenUrl: environments_js_1.defaultEnvironmentConfig[environments_js_1.Environment.Emulator].tokenUrl,
    });
    it("Authenticate token gets reused", async () => {
        const t1 = await auth.getToken();
        await (0, helpers_js_1.delay)(1000);
        const t2 = await auth.getToken();
        chai_1.assert.equal(t1, t2);
    });
    it("Authenticate expired token gets refreshed", async () => {
        const t1 = await auth.getToken();
        await (0, helpers_js_1.delay)(1000);
        const fakeClock = sinon_1.default.useFakeTimers(new Date());
        fakeClock.tick(2 * 24 * 60 * 60 * 1000);
        const t2 = await auth.getToken();
        fakeClock.restore();
        chai_1.assert.notEqual(t1, t2);
    });
});
