"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const helpers_js_1 = require("./helpers.js");
const scopes_js_1 = require("../configuration/scopes.js");
const api_js_1 = require("../api.js");
describe("Countries", async () => {
    it("Countries find", async () => {
        const result = await helpers_js_1.client.countries.find();
        const country = result.data.find((c) => c.nameEn === "Netherlands");
        if (!country)
            throw Error("Country not defined");
        chai_1.assert.equal(country.uid, helpers_js_1.countryUid);
        chai_1.assert.equal(country.nameNative, "Nederland");
        chai_1.assert.equal(country.nameNo, "Nederland");
    });
    it("Countries find with invalid scope", async () => {
        try {
            const config = (0, helpers_js_1.getDefaultConfig)();
            config.scopes = [scopes_js_1.Scope.PersonsRead];
            const clientWithOutScope = new api_js_1.CoreApiClient(config);
            await clientWithOutScope.countries.find();
            chai_1.assert.fail("Was able to find with an invalid scope");
        }
        catch (err) {
            if (!(0, api_js_1.isCoreApiError)(err))
                throw Error("Invalid error type");
            chai_1.assert.equal(err.details.code, api_js_1.ErrorCode.MissingScopes);
        }
    });
});
