"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const helpers_js_1 = require("./helpers.js");
const api_js_1 = require("../api.js");
const chai_1 = require("chai");
describe("Test random crud operations", async () => {
    beforeEach(async () => {
        await helpers_js_1.client.refreshTestData();
    });
    it("Find person", async () => {
        const result = await helpers_js_1.client.persons.find();
        chai_1.assert.instanceOf(result, api_js_1.WrappedWithMetaArrayPerson);
        chai_1.assert.isAbove(result.meta.total, 0);
    });
    it("Get person by ID lookup", async () => {
        const result = await helpers_js_1.client.persons.lookupPersonId(helpers_js_1.person1Uid);
        chai_1.assert.instanceOf(result, api_js_1.WrappedInt);
        chai_1.assert.equal(result.data, 54512);
    });
    it("Get Relation", async () => {
        const result = await helpers_js_1.client.relations.get(helpers_js_1.relationUid);
        chai_1.assert.instanceOf(result, api_js_1.WrappedRelation);
    });
    it("Update and create consent", async () => {
        const consent = await helpers_js_1.client.consents.get(helpers_js_1.person1ActiveConsentUid);
        await helpers_js_1.client.consents.update(consent.data.uid, {
            orgUid: consent.data.orgUid,
            personUid: consent.data.personUid,
            purpose: consent.data.purpose,
            validFrom: consent.data.validFrom,
            validTo: new Date(),
        });
        const result = await helpers_js_1.client.consents.create({
            orgUid: helpers_js_1.org1Uid,
            personUid: helpers_js_1.person1Uid,
            purpose: api_js_1.ConsentPurpose.DataSharing,
            validFrom: new Date(),
        });
        chai_1.assert.instanceOf(result, api_js_1.WrappedConsent);
    });
    it("Remove affiliation", async () => {
        const res = await helpers_js_1.client.affiliations.remove(helpers_js_1.affiliationUid);
        chai_1.assert.instanceOf(res, api_js_1.WrappedAffiliation);
        try {
            await helpers_js_1.client.affiliations.get(helpers_js_1.affiliationUid);
            chai_1.assert.fail("Should not find affiliation");
        }
        catch (err) {
            if (!(0, api_js_1.isCoreApiError)(err))
                throw Error("Invalid error type");
            chai_1.assert.equal(err.details.code, api_js_1.ErrorCode.NotFound);
        }
    });
});
