import { affiliationUid, client, org1Uid, person1ActiveConsentUid, person1Uid, relationUid, } from "./helpers.js";
import { ConsentPurpose, ErrorCode, WrappedAffiliation, WrappedConsent, WrappedInt, WrappedRelation, WrappedWithMetaArrayPerson, isCoreApiError, } from "../api.js";
import { assert } from "chai";
describe("Test random crud operations", async () => {
    beforeEach(async () => {
        await client.refreshTestData();
    });
    it("Find person", async () => {
        const result = await client.persons.find();
        assert.instanceOf(result, WrappedWithMetaArrayPerson);
        assert.isAbove(result.meta.total, 0);
    });
    it("Get person by ID lookup", async () => {
        const result = await client.persons.lookupPersonId(person1Uid);
        assert.instanceOf(result, WrappedInt);
        assert.equal(result.data, 54512);
    });
    it("Get Relation", async () => {
        const result = await client.relations.get(relationUid);
        assert.instanceOf(result, WrappedRelation);
    });
    it("Update and create consent", async () => {
        const consent = await client.consents.get(person1ActiveConsentUid);
        await client.consents.update(consent.data.uid, {
            orgUid: consent.data.orgUid,
            personUid: consent.data.personUid,
            purpose: consent.data.purpose,
            validFrom: consent.data.validFrom,
            validTo: new Date(),
        });
        const result = await client.consents.create({
            orgUid: org1Uid,
            personUid: person1Uid,
            purpose: ConsentPurpose.DataSharing,
            validFrom: new Date(),
        });
        assert.instanceOf(result, WrappedConsent);
    });
    it("Remove affiliation", async () => {
        const res = await client.affiliations.remove(affiliationUid);
        assert.instanceOf(res, WrappedAffiliation);
        try {
            await client.affiliations.get(affiliationUid);
            assert.fail("Should not find affiliation");
        }
        catch (err) {
            if (!isCoreApiError(err))
                throw Error("Invalid error type");
            assert.equal(err.details.code, ErrorCode.NotFound);
        }
    });
});
