import { assert } from "chai";
import { affiliationUid, client, getDefaultConfig } from "./helpers.js";
import { CoreApiClient, ErrorCode, isCoreApiError } from "../api.js";
import { CoreApiError } from "../model/error.js";
import { Scope } from "../configuration/scopes.js";
describe("Errors", async () => {
    it("Test error helpers", () => {
        function throwFunction() {
            throw new CoreApiError({
                error: {
                    code: ErrorCode.InvalidBody,
                    message: "test message",
                },
            });
        }
        try {
            throwFunction();
        }
        catch (err) {
            if (!isCoreApiError(err))
                throw "Invalid error type";
            assert.equal(err.details.code, ErrorCode.InvalidBody);
            assert.equal(err.message, "test message");
        }
    });
    it("Invalid scope error", async () => {
        try {
            const config = getDefaultConfig();
            config.scopes = [Scope.ConsentsRead];
            const clientWithOutScope = new CoreApiClient(config);
            await clientWithOutScope.affiliations.get(affiliationUid);
            assert.fail("Was able to remove with an invalid scope");
        }
        catch (err) {
            if (!(err instanceof CoreApiError))
                assert.fail("Invalid error type");
            assert.equal(err.details.code, ErrorCode.MissingScopes);
            assert.equal(err.message, "missing scope: needs: persons.affiliations#read");
        }
    });
    it("Non existing error", async () => {
        try {
            const fakeUid = "657a66ca-9cd0-4b61-9476-697016e26fbc";
            await client.affiliations.get(fakeUid);
            assert.fail("Was able to remove with a non existing affiliation");
        }
        catch (err) {
            if (!(err instanceof CoreApiError))
                assert.fail("Invalid error type");
            assert.equal(err.details.code, ErrorCode.NotFound);
        }
    });
});
