import { assert } from "chai";
import { child1Uid, client, groupUid } from "./helpers.js";
import { GroupType } from "../api.js";
describe("Groups", async () => {
    beforeEach(async () => {
        await client.refreshTestData();
    });
    it("Groups find", async () => {
        const result = await client.groups.find();
        assert.isNotEmpty(result.data);
    });
    it("Groups create", async () => {
        const result = await client.groups.create({
            name: "Test",
            type: GroupType.Dynamic,
            rule: `{"displayName": {"_gt": "A"}}`,
            tags: ["Notifications"],
        });
        assert.equal(result.data.name, "Test");
        assert.equal(result.data.rule, `{"displayName": {"_gt": "A"}}`);
    });
    it("Groups add member", async () => {
        const result = await client.groups.addMember(groupUid, {
            personUid: child1Uid,
        });
        assert.equal(result.data.personUid, child1Uid);
        assert.equal(result.data.groupUid, groupUid);
    });
    it("Groups find members", async () => {
        const result = await client.groups.findMembers(groupUid);
        assert.isNotEmpty(result.data);
    });
});
